=== modified file 'plugin/md5/md5.cc'
--- plugin/md5/md5.cc	2010-03-24 19:45:37 +0000
+++ plugin/md5/md5.cc	2010-05-04 05:04:57 +0000
@@ -68,10 +68,12 @@
 
   null_value= false;
 
-  unsigned char digest[16];
   str->set_charset(&my_charset_bin);
 
-  gcry_md_hash_buffer(GCRY_MD_MD5, digest, sptr->ptr(), sptr->length());
+  gcry_md_hd_t md5_context;
+  gcry_md_open(&md5_context, GCRY_MD_MD5, 0);
+  gcry_md_write(md5_context, sptr->ptr(), sptr->length());  
+  unsigned char *digest= gcry_md_read(md5_context, 0);
 
   snprintf((char *) str->ptr(), 33,
     "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
@@ -81,6 +83,8 @@
     digest[12], digest[13], digest[14], digest[15]);
   str->length((uint32_t) 32);
 
+  gcry_md_close(md5_context);
+
   return str;
 }
 
@@ -89,6 +93,18 @@
 
 static int initialize(plugin::Context &context)
 {
+  /* Initialize libgcrypt */
+  if (not gcry_check_version(GCRYPT_VERSION))
+  {
+    errmsg_printf(ERRMSG_LVL_ERROR, _("libgcrypt library version mismatch\n"));
+    return 1;
+  }
+  /* Disable secure memory.  */
+  gcry_control (GCRYCTL_DISABLE_SECMEM, 0);
+
+  /* Tell Libgcrypt that initialization has completed. */
+  gcry_control (GCRYCTL_INITIALIZATION_FINISHED, 0);
+
   md5udf= new plugin::Create_function<Md5Function>("md5");
   context.add(md5udf);
   return 0;

=== modified file 'tests/valgrind.supp'
--- tests/valgrind.supp	2010-04-20 00:00:46 +0000
+++ tests/valgrind.supp	2010-05-04 05:04:57 +0000
@@ -2131,3 +2131,16 @@
    fun:mem_heap_create_block
    ...
 }
+
+{
+  Static buffer created on gcrypt library initialization. Not a leak.
+  Memcheck:Leak
+  fun:malloc
+  ...
+  obj:*libgcrypt.so.*
+  fun:_ZL10initializeRN8drizzled6plugin7ContextE
+  fun:_ZN8drizzled11plugin_initERNS_6plugin8RegistryEPiPPcb
+  fun:_ZN8drizzled22init_server_componentsERNS_6plugin8RegistryE
+  fun:main
+}
+

